.. image:: https://img.shields.io/travis/Nekmo/os3.svg?style=flat-square&maxAge=2592000
  :target: https://travis-ci.org/Nekmo/os3
  :alt: Latest Travis CI build status

.. image:: https://img.shields.io/pypi/v/os3.svg?style=flat-square
  :target: https://pypi.python.org/pypi/os3
  :alt: Latest PyPI version

.. image:: https://img.shields.io/pypi/pyversions/os3.svg?style=flat-square
  :target: https://pypi.python.org/pypi/os3
  :alt: Python versions

.. image:: https://img.shields.io/codeclimate/github/Nekmo/os3.svg?style=flat-square
  :target: https://codeclimate.com/github/Nekmo/os3
  :alt: Code Climate

.. image:: https://img.shields.io/codecov/c/github/Nekmo/os3/master.svg?style=flat-square
  :target: https://codecov.io/github/Nekmo/os3
  :alt: Test coverage

.. image:: https://img.shields.io/requires/github/Nekmo/os3.svg?style=flat-square
     :target: https://requires.io/github/Nekmo/os3/requirements/?branch=master
     :alt: Requirements Status

.. role:: strike
    :class: strike
